@@ -1,5 +1,5 @@
 #!/bin/bash
-set -x
+set -euxo pipefail
 cpanm Dist::Zilla
 dzil authordeps --missing | cpanm
 dzil listdeps --missing | cpanm
